@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //*************************************************************************
 //
-// Copyright 2009-2011 by Wilson Snyder.  This program is free software;
+// Copyright 2009-2013 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the
 // GNU Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -43,7 +43,7 @@ public:
     enum en {
 	NOT_FOUND = 0,
 	NETLIST = 1,	// Top of structure, created by Parser.pm:sub new{}
-	ERROR = 2,	// Consistency error in internal tables
+	AN_ERROR = 2,	// Consistency error in internal tables (ERROR alone is a #define on some systems)
 	UNKNOWN = 3,	// Things that need scope, but don't know type yet
 	//
 	BLOCK,
